@@ -20,10 +20,11 @@ import omero
 from omero.gateway import BlitzGateway
 from logfile_parser import Parser
 
+from agora.io.utils import accumulate
 from aliby.timelapse import TimelapseOMERO, TimelapseLocal
-from aliby.utils import accumulate
 
-from aliby.io.writer import Writer
+from agora.io.metadata_parser import parse_logfiles
+from agora.io.writer import Writer
 
 logger = logging.getLogger(__name__)
 
@@ -97,10 +98,6 @@ def get_data_lazy(image) -> da.Array:
     return da.stack(t_stacks)
 
 
-# Metadata writer
-from aliby.io.metadata_parser import parse_logfiles
-
-
 class MetaData:
     """Small metadata Process that loads log."""
 
